@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import os
 from dataclasses import dataclass, field
 from datetime import datetime
 from enum import Enum
@@ -9,6 +10,7 @@ from google.cloud import datastore
 
 from gcp_pilot import exceptions
 
+DEFAULT_NAMESPACE = os.environ.get('GCP_DATASTORE_NAMESPACE', default=None)
 DEFAULT_PK_FIELD = 'id'
 MAX_ITEMS_PER_OPERATIONS = 500  # Datastore cannot write more than 500 items per call
 
@@ -31,11 +33,11 @@ class MultipleObjectsFound(Exception):
     filters: Dict
 
 
-def _starts_with_operator(lookup_fields, value):
+def _starts_with_operator(lookup_fields, value) -> List[Tuple[str, str, Any]]:
     field_name = '.'.join(lookup_fields)
     return [
-        [field_name, '>=', value],
-        [field_name, '<=', f'{value}\ufffd'],
+        (field_name, '>=', value),
+        (field_name, '<=', f'{value}\ufffd'),
     ]
 
 
@@ -180,7 +182,7 @@ class Manager:
                 f"Querying with OR clause is not supported"
             )
 
-        return ['.'.join(lookup_fields), (operator or '='), value]
+        return [('.'.join(lookup_fields), (operator or '='), value)]
 
     def to_entity(self, obj: Document) -> datastore.Entity:
         entity = datastore.Entity(key=self.build_key(pk=obj.pk))
@@ -201,13 +203,13 @@ class Metadata:
     fields: Dict[str, type]
     doc_klass: Type[EmbeddedDocument]
     pk_field: str = None
-    namespace: str = None
+    namespace: str = DEFAULT_NAMESPACE
 
     def from_dict(self, data: Dict) -> EmbeddedDocument:
         data = data.copy()
 
         def _build(klass: Union[EmbeddedDocument, Callable], value: Any):
-            if value is None:
+            if value is None or klass == Any:
                 return value
 
             if issubclass(klass, EmbeddedDocument):
