@@ -7,7 +7,7 @@ from gcp_pilot.base import GoogleCloudPilotAPI, AccountManagerMixin, PolicyType,
 AccountType = Dict[str, Any]
 
 
-class IAM(AccountManagerMixin, DiscoveryMixin, GoogleCloudPilotAPI):
+class IdentityAccessManager(AccountManagerMixin, DiscoveryMixin, GoogleCloudPilotAPI):
     def __init__(self, **kwargs):
         super().__init__(
             serviceName='iam',
@@ -16,11 +16,8 @@ class IAM(AccountManagerMixin, DiscoveryMixin, GoogleCloudPilotAPI):
             **kwargs,
         )
 
-    def _parent_path(self, project_id: str = None) -> str:
-        return f'projects/{project_id or self.project_id}'
-
     def _service_account_path(self, email: str, project_id: str = None) -> str:
-        parent_path = self._parent_path(project_id=project_id)
+        parent_path = self._project_path(project_id=project_id)
         return f'{parent_path}/serviceAccounts/{email}'
 
     def _build_service_account_email(self, name: str, project_id: str = None) -> str:
@@ -53,7 +50,7 @@ class IAM(AccountManagerMixin, DiscoveryMixin, GoogleCloudPilotAPI):
             }
             service_account = self._execute(
                 method=self.client.projects().serviceAccounts().create,
-                name=self._parent_path(project_id=project_id),
+                name=self._project_path(project_id=project_id),
                 body=body,
             )
         except exceptions.AlreadyExists:
@@ -64,7 +61,7 @@ class IAM(AccountManagerMixin, DiscoveryMixin, GoogleCloudPilotAPI):
 
     async def list_service_accounts(self, project_id: str = None) -> Generator[AccountType, None, None]:
         params = dict(
-            name=self._parent_path(project_id=project_id),
+            name=self._project_path(project_id=project_id),
         )
         pagination = self._paginate(
             method=self.client.projects().serviceAccounts().list,
@@ -81,14 +78,14 @@ class IAM(AccountManagerMixin, DiscoveryMixin, GoogleCloudPilotAPI):
             resource=resource,
         )
 
-    def as_member(self, email: str) -> str:
+    def _as_member(self, email: str) -> str:
         is_service_account = email.endswith('.gserviceaccount.com')
         prefix = 'serviceAccount' if is_service_account else 'member'
         return f'{prefix}:{email}'
 
     async def bind_member(self, target_email: str, member_email: str, role: str, project_id=None) -> PolicyType:
         policy = self.get_policy(email=target_email, project_id=project_id)
-        changed_policy = self.bind_email_to_policy(email=member_email, role=role, policy=policy)
+        changed_policy = self._bind_email_to_policy(email=member_email, role=role, policy=policy)
         return self.set_policy(email=target_email, policy=changed_policy, project_id=project_id)
 
     async def remove_member(
@@ -99,7 +96,7 @@ class IAM(AccountManagerMixin, DiscoveryMixin, GoogleCloudPilotAPI):
             project_id: str = None,
     ) -> PolicyType:
         policy = self.get_policy(email=target_email, project_id=project_id)
-        changed_policy = self.unbind_email_from_policy(email=member_email, role=role, policy=policy)
+        changed_policy = self._unbind_email_from_policy(email=member_email, role=role, policy=policy)
         return self.set_policy(email=target_email, policy=changed_policy, project_id=project_id)
 
     def set_policy(self, email: str, policy: PolicyType, project_id: str = None) -> PolicyType:
@@ -109,3 +106,8 @@ class IAM(AccountManagerMixin, DiscoveryMixin, GoogleCloudPilotAPI):
             resource=resource,
             body={'policy': policy, 'updateMask': 'bindings'},
         )
+
+
+__all__ = (
+    'IdentityAccessManager',
+)
